@@ -53,7 +53,7 @@ class CodePipelineStack(Stack):
         self._connections = {}
         for name, connection in values.items():
             if not connection.startswith('arn:aws:codestar-connections') and not connection.startswith('dummy-value-for-'):
-                logging.warning(f"{name} not a CS arn {connection} - {self.is_construct()}")
+                logging.warning(f"{name} not a CS arn {connection}")
             self._connections[name] = connection
 
     def add_connections(self, values: dict) -> typing.Dict[str, aws_codestarconnections.CfnConnection]:
